# Moya

Moya is a platform for the rapid development of modern web applications.

## Installation

You can install from PyPi with the following:

```
pip install moya
```

Or download the repos and run the following:

```
python setup.py install
```

Which ever method you use, this will add a `moya` command line application.

## Quick Start

Moya quick start will create a basic web application based on your specifications in seconds.

Run the following to get started:

```
moya start project
```

## Example Projects

In addition to the `example projects` directory in the Moya repos, you can check out the following complete projects:

* [Moya Techblog](https://github.com/moyaproject/moya-techblog)
  A blogging application for coders and photographers

* [Bean Counter](https://github.com/moyaproject/beancounter)
  A virtual currency platform

* [Encrypted Notes](https://github.com/moyaproject/notes)
  An encrypted note taking application

* [Social Links](https://github.com/moyaproject/sociallinks)
  A social linking (Reddit like) application

* [Short URL](https://github.com/moyaproject/shorturl)
  A super simple URL shortener application

## Running a project

Navigate to the project directory you want to run, then do the following:

```
moya init
```

This will initialize the database and users system. You only need to do this once.

To run a development server, do the following:

```
moya runserver
```

And navigate to http://127.0.0.1:8000


## Package Index

Find packages for Moya on the [Moya Package Index](https://packages.moyaproject.com).

Install packages `moya-pm` which comes with Moya:

```
moya-pm install moya.sociallinks
```


## More Information

 * [Moya Homepage](http://www.moyaproject.com/)
 * [Moya's Documentation](http://docs.moyaproject.com/)
 * [Developer's Blog](https://www.willmcgugan.com/tag/moya/)
